@@ -1,7 +1,7 @@
 ## Gnuplot.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the gnuplot part of the package.
 ##
-## $Id: Gnuplot.pm,v 1.45 2006/06/02 23:33:07 emile Exp $ $Name:  $
+## $Id: Gnuplot.pm,v 1.48 2006/06/07 21:09:33 emile Exp $ $Name:  $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -49,12 +49,12 @@ use Chart::Graph::Utils qw(:UTILS);	# get global subs and variable
 use POSIX 'strftime';
 use FileHandle;
 
-$cvs_Id = '$Id: Gnuplot.pm,v 1.45 2006/06/02 23:33:07 emile Exp $';
+$cvs_Id = '$Id: Gnuplot.pm,v 1.48 2006/06/07 21:09:33 emile Exp $';
 $cvs_Author = '$Author: emile $';
 $cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.45 $';
+$cvs_Revision = '$Revision: 1.48 $';
 
-$VERSION = 3.1;
+$VERSION = 3.2;
 
 use strict;
 
@@ -1283,7 +1283,7 @@ and the last is an external data file.
             'type' => 'file'}, './samplefile'],);
 
 =for html
-<p><center><img src="http://http://www.caida.org/tools/utilities/graphing/gnuplot1.png"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/gnuplot1.png"></center></p>
 <p><center><em>gnuplot1.png</em></center></p>
 
 =head2 ERRORBARS
